import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import aspects-security-group._jsii
import aws_cdk._jsii
import constructs._jsii
import managed_instance_role._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "@renovosolutions/cdk-library-renovo-instance-service",
    "2.6.23",
    __name__[0:-6],
    "cdk-library-renovo-instance-service@2.6.23.jsii.tgz",
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
